@@ -6,6 +6,4 @@
 #undef HAVE_GETTEXT
 #undef HAVE_LC_MESSAGES
 #undef HAVE_STPCPY
-#undef HAVE_GTKHTML
-#undef HAVE_GHTTP
-#undef HAVE_GAL
+#undef HAVE_PERL
