@@ -101,8 +101,8 @@ builder_control_new (void)
 		gnome_db_control_set_user_data(control, (gpointer) control_data);
 
 		/* set menus/toolbar */
-		gnome_db_control_set_menubar(control, mainmenu);
-		gnome_db_control_set_toolbar(control, toolbar);
+		//gnome_db_control_set_menubar(control, mainmenu);
+		//gnome_db_control_set_toolbar(control, toolbar);
 	}
 	
 	return BONOBO_OBJECT(control);
