@@ -51,11 +51,12 @@ owner_unset_cb (GnomeDbControl *control, gpointer user_data)
 		GdaConnectionPool *pool = components_connection_get_pool ();
 
 		/* terminate all connections before finishing */
-		if (IS_GDA_CONNECTION_POOL (pool)) {
+		if (GDA_IS_CONNECTION_POOL (pool)) {
 			gda_connection_pool_close_all (pool);
 			gda_connection_pool_free (pool);
 		}
 
+		components_config_save ();
 		gnome_db_main_quit ();
 	}
 }
