@@ -19,8 +19,9 @@
 #if !defined(__gnomedb_monikers_h__)
 #  define __gnomedb_monikers_h__
 
-#include <config.h>
+#include "config.h"
 #include <gnome-db.h>
+#include <libgnome/gnome-i18n.h>
 
 BEGIN_GNOME_DECLS
 
