@@ -16,12 +16,13 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include <bonobo/bonobo-ui-engine.h>
 #include <gnomedb-fe.h>
 
 static GList* activated_components = NULL;
 
 void
-fe_about_cb (GtkWidget *w, gpointer user_data)
+fe_about_cb (BonoboUIComponent *uic, void *data, const char *path)
 {
 	gnome_db_show_about_dialog("GNOME-DB Front End");
 }
@@ -56,7 +57,7 @@ fe_activate_component_cb (GtkWidget *w, gpointer user_data)
 }
 
 void
-fe_do_copy_clipboard_cb (GtkWidget *w, gpointer user_data)
+fe_do_copy_clipboard_cb (BonoboUIComponent *uic, void *data, const char *path)
 {
 	GtkWidget* tab = fe_workarea_get_current_tab();
 	if (GNOME_DB_IS_CONTROL_WIDGET(tab)) {
@@ -65,7 +66,7 @@ fe_do_copy_clipboard_cb (GtkWidget *w, gpointer user_data)
 }
 
 void
-fe_do_cut_clipboard_cb (GtkWidget *w, gpointer user_data)
+fe_do_cut_clipboard_cb (BonoboUIComponent *uic, void *data, const char *path)
 {
 	GtkWidget* tab = fe_workarea_get_current_tab();
 	if (GNOME_DB_IS_CONTROL_WIDGET(tab)) {
@@ -74,7 +75,7 @@ fe_do_cut_clipboard_cb (GtkWidget *w, gpointer user_data)
 }
 
 void
-fe_do_paste_clipboard_cb (GtkWidget *w, gpointer user_data)
+fe_do_paste_clipboard_cb (BonoboUIComponent *uic, void *data, const char *path)
 {
 	GtkWidget* tab = fe_workarea_get_current_tab();
 	if (GNOME_DB_IS_CONTROL_WIDGET(tab)) {
@@ -83,7 +84,7 @@ fe_do_paste_clipboard_cb (GtkWidget *w, gpointer user_data)
 }
 
 void
-fe_do_print_cb (GtkWidget *w, gpointer user_data)
+fe_do_print_cb (BonoboUIComponent *uic, void *data, const char *path)
 {
 	GtkWidget* tab = fe_workarea_get_current_tab();
 	if (GNOME_DB_IS_CONTROL_WIDGET(tab)) {
@@ -92,13 +93,13 @@ fe_do_print_cb (GtkWidget *w, gpointer user_data)
 }
 
 void
-fe_new_database_cb (GtkWidget *w, gpointer user_data)
+fe_new_database_cb (BonoboUIComponent *uic, void *data, const char *path)
 {
 	fe_wizard_new_database();
 }
 
 void
-fe_open_gnome_db_manual_cb (GtkWidget *w, gpointer user_data)
+fe_open_gnome_db_manual_cb (BonoboUIComponent *uic, void *data, const char *path)
 {
 	gchar *filename;
 
@@ -110,7 +111,7 @@ fe_open_gnome_db_manual_cb (GtkWidget *w, gpointer user_data)
 }
 
 void
-fe_open_libgda_manual_cb (GtkWidget *w, gpointer user_data)
+fe_open_libgda_manual_cb (BonoboUIComponent *uic, void *data, const char *path)
 {
 	gchar *filename;
 
@@ -122,7 +123,7 @@ fe_open_libgda_manual_cb (GtkWidget *w, gpointer user_data)
 }
 
 void
-fe_open_libgda_reference_cb (GtkWidget *w, gpointer user_data)
+fe_open_libgda_reference_cb (BonoboUIComponent *uic, void *data, const char *path)
 {
 	gchar *filename;
 
@@ -134,13 +135,13 @@ fe_open_libgda_reference_cb (GtkWidget *w, gpointer user_data)
 }
 
 void
-fe_preferences_cb (GtkWidget *w, gpointer user_data)
+fe_preferences_cb (BonoboUIComponent *uic, void *data, const char *path)
 {
 	fe_config_open_dialog();
 }
 
 void
-fe_quit_cb (GtkWidget *w, gpointer user_data)
+fe_quit_cb (BonoboUIComponent *uic, void *data, const char *path)
 {
 	GList *l;
 
@@ -160,7 +161,7 @@ fe_quit_cb (GtkWidget *w, gpointer user_data)
 
 #if defined(HAVE_PERL)
 void
-fe_run_perl_cb (GtkWidget *w, gpointer data)
+fe_run_perl_cb (BonoboUIComponent *uic, void *data, const char *path)
 {
 	gchar *filename;
 
@@ -175,7 +176,7 @@ fe_run_perl_cb (GtkWidget *w, gpointer data)
 #endif
 
 void
-fe_show_shortcut_bar_cb (GtkWidget *w, gpointer user_data)
+fe_show_shortcut_bar_cb (BonoboUIComponent *uic, void *data, const char *path)
 {
 	if (fe_workarea_shortcut_is_visible ())
 		fe_workarea_hide_shortcut ();
