@@ -31,22 +31,23 @@ BEGIN_GNOME_DECLS
 /*
  * Callbacks
  */
-void fe_about_cb                 (GtkWidget *w, gpointer user_data);
 void fe_activate_component_cb    (GtkWidget *w, gpointer user_data);
-void fe_do_copy_clipboard_cb     (GtkWidget *w, gpointer user_data);
-void fe_do_cut_clipboard_cb      (GtkWidget *w, gpointer user_data);
-void fe_do_paste_clipboard_cb    (GtkWidget *w, gpointer user_data);
-void fe_do_print_cb              (GtkWidget *w, gpointer user_data);
-void fe_new_database_cb          (GtkWidget *w, gpointer user_data);
-void fe_open_gnome_db_manual_cb  (GtkWidget *w, gpointer user_data);
-void fe_open_libgda_manual_cb    (GtkWidget *w, gpointer user_data);
-void fe_open_libgda_reference_cb (GtkWidget *w, gpointer user_data);
-void fe_preferences_cb           (GtkWidget *w, gpointer user_data);
-void fe_quit_cb                  (GtkWidget *w, gpointer user_data);
+
+void fe_about_cb                 (BonoboUIComponent *uic, void *data, const char *path);
+void fe_do_copy_clipboard_cb     (BonoboUIComponent *uic, void *data, const char *path);
+void fe_do_cut_clipboard_cb      (BonoboUIComponent *uic, void *data, const char *path);
+void fe_do_paste_clipboard_cb    (BonoboUIComponent *uic, void *data, const char *path);
+void fe_do_print_cb              (BonoboUIComponent *uic, void *data, const char *path);
+void fe_new_database_cb          (BonoboUIComponent *uic, void *data, const char *path);
+void fe_open_gnome_db_manual_cb  (BonoboUIComponent *uic, void *data, const char *path);
+void fe_open_libgda_manual_cb    (BonoboUIComponent *uic, void *data, const char *path);
+void fe_open_libgda_reference_cb (BonoboUIComponent *uic, void *data, const char *path);
+void fe_preferences_cb           (BonoboUIComponent *uic, void *data, const char *path);
+void fe_quit_cb                  (BonoboUIComponent *uic, void *data, const char *path);
 #if defined(HAVE_PERL)
-void fe_run_perl_cb              (GtkWidget *w, gpointer user_data);
+void fe_run_perl_cb              (BonoboUIComponent *uic, void *data, const char *path);
 #endif
-void fe_show_shortcut_bar_cb     (GtkWidget *w, gpointer user_data);
+void fe_show_shortcut_bar_cb     (BonoboUIComponent *uic, void *data, const char *path);
 
 /*
  * Configuration
@@ -84,7 +85,8 @@ extern GtkWidget*  glb_mainwin;
 #define GNOMEDB_FE_CONFIG_SECTION_MAIN "/apps/gnome-db/Frontend"
 #define GNOMEDB_FE_CONFIG_SECTION_LOAD "/apps/gnome-db/Frontend/Load"
 
-#define GNOMEDB_FE_CONFIG_KEY_SAVE_WINDOW_POS "/apps/gnome-db/Frontend/General/SaveWindowPos"
+#define GNOMEDB_FE_CONFIG_KEY_SAVE_WINDOW_POS   "/apps/gnome-db/Frontend/General/SaveWindowPos"
+#define GNOMEDB_FE_CONFIG_KEY_SHOW_SHORTCUT_BAR "/apps/gnome-db/Frontend/General/ShowShortcutBar"
 
 END_GNOME_DECLS
 
