@@ -20,8 +20,8 @@
 #if !defined(__gnome_db_component_h__)
 #  define __gnome_db_component_h__
 
-#include <gnome.h>
-#include <bonobo.h>
+#include <libgnome/gnome-defs.h>
+#include <bonobo/bonobo-object.h>
 
 BEGIN_GNOME_DECLS
 
@@ -34,15 +34,12 @@ BEGIN_GNOME_DECLS
 typedef struct _GnomeDbComponent      GnomeDbComponent;
 typedef struct _GnomeDbComponentClass GnomeDbComponentClass;
 
-struct _GnomeDbComponent
-{
-  BonoboObject          bonobo_object;
-  BonoboGenericFactory* factory;
+struct _GnomeDbComponent {
+	BonoboObject          bonobo_object;
 };
 
-struct _GnomeDbComponentClass
-{
-  BonoboObjectClass parent_class;
+struct _GnomeDbComponentClass {
+	BonoboObjectClass parent_class;
 };
 
 GtkType    gnome_db_component_get_type (void);
