@@ -133,28 +133,28 @@ gnome_db_dataset_init (GnomeDbDataset *dset)
 	gtk_container_add(GTK_CONTAINER(frame), table);
 	
 	/* create top toolbar */
-	dset->first_btn = gnome_db_new_button_widget_with_pixmap("", GNOME_STOCK_MENU_FIRST);
+	dset->first_btn = gnome_db_new_button_widget_with_pixmap(" ", GNOME_STOCK_MENU_FIRST);
 	gtk_signal_connect(GTK_OBJECT(dset->first_btn),
 	                   "clicked",
 	                   GTK_SIGNAL_FUNC(go_first_cb),
 	                   (gpointer) dset);
 	gtk_table_attach(GTK_TABLE(table), dset->first_btn, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 3, 3);
 
-	dset->previous_btn = gnome_db_new_button_widget_with_pixmap("", GNOME_STOCK_MENU_BACK);
+	dset->previous_btn = gnome_db_new_button_widget_with_pixmap(" ", GNOME_STOCK_MENU_BACK);
 	gtk_signal_connect(GTK_OBJECT(dset->previous_btn),
 	                   "clicked",
 	                   GTK_SIGNAL_FUNC(go_previous_cb),
 	                   (gpointer) dset);
 	gtk_table_attach(GTK_TABLE(table), dset->previous_btn, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 3, 3);
 
-	dset->next_btn = gnome_db_new_button_widget_with_pixmap("", GNOME_STOCK_MENU_FORWARD);
+	dset->next_btn = gnome_db_new_button_widget_with_pixmap(" ", GNOME_STOCK_MENU_FORWARD);
 	gtk_signal_connect(GTK_OBJECT(dset->next_btn),
 	                   "clicked",
 	                   GTK_SIGNAL_FUNC(go_next_cb),
 	                   (gpointer) dset);
 	gtk_table_attach(GTK_TABLE(table), dset->next_btn, 2, 3, 0, 1, GTK_FILL, GTK_FILL, 3, 3);
 
-	dset->last_btn = gnome_db_new_button_widget_with_pixmap("", GNOME_STOCK_MENU_LAST);
+	dset->last_btn = gnome_db_new_button_widget_with_pixmap(" ", GNOME_STOCK_MENU_LAST);
 	gtk_signal_connect(GTK_OBJECT(dset->last_btn),
 	                   "clicked",
 	                   GTK_SIGNAL_FUNC(go_last_cb),
@@ -276,7 +276,7 @@ gnome_db_dataset_set_recordset (GnomeDbDataset *dset, GdaRecordset *recset)
 			GtkWidget* entry;
 			GdaField* field = gda_recordset_field_idx(dset->recset, cnt);
 			
-			label = gnome_db_new_label_widget(gda_field_name(field));
+			label = gnome_db_new_label_widget(gda_field_get_name(field));
 			gtk_table_attach(GTK_TABLE(dset->container), label, 0, 1, cnt, cnt + 1,
 			                 GTK_FILL, GTK_FILL, 3, 3);
 
