@@ -1,5 +1,8 @@
 /* GNOME DB libary
- * Copyright (C) 1999 Rodrigo Moya
+ * Copyright (C), 1999-2001 The Free Software Foundation
+ *
+ * AUTHORS:
+ *	Rodrigo Moya <rodrigo@gnome-db.org>
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -35,11 +38,10 @@ BEGIN_GNOME_DECLS
 typedef struct _GnomeDbDataset      GnomeDbDataset;
 typedef struct _GnomeDbDatasetClass GnomeDbDatasetClass;
 
-struct _GnomeDbDataset
-{
+struct _GnomeDbDataset {
 	GtkVBox       vbox;
 
-	/* do not use the fields in this structure! Radical changes may take place */
+	/* do not access these fields directly */
 	GtkWidget*    frame;
 	GtkWidget*    container;
 	GtkWidget*    first_btn;
@@ -50,8 +52,7 @@ struct _GnomeDbDataset
 	GList*        entries;
 };
 
-struct _GnomeDbDatasetClass
-{
+struct _GnomeDbDatasetClass {
 	GtkVBoxClass parent_class;
 };
 
