@@ -119,10 +119,10 @@ show_table_detail (GnomeDbDesigner *designer, xmlNodePtr xmlnode)
 	gint       field_count;
 	gint       cnt;
 	const gchar*clist_titles[] = { N_("Name"), N_("GDA Type"), N_("Size"), N_("Scale") };
-	
+
 	g_return_val_if_fail(GNOME_DB_IS_DESIGNER(designer), NULL);
 	g_return_val_if_fail(xmlnode != NULL, NULL);
-	
+
 	/* create container */
 	container = gnome_db_new_table_widget(1, 4, FALSE);
 	
@@ -205,7 +205,8 @@ select_tree_row_cb (GtkCTree *ctree, GtkCTreeNode *row, gint column, GnomeDbDesi
 	
 	xmlnode = (xmlNodePtr) gtk_ctree_node_get_row_data(ctree, row);
 	if (xmlnode) {
-		if (xmlnode->parent == gda_xml_database_get_tables(designer->priv->xmldb)) {
+		if (gda_xml_database_table_find (designer->priv->xmldb,
+						 xmlGetProp (xmlnode, "name"))) {
 			designer->priv->detail = show_table_detail(designer, xmlnode);
 		}
 		
@@ -226,11 +227,11 @@ table_add_field_cb (GtkWidget *w, gpointer user_data)
 
 	g_return_if_fail(GTK_IS_CLIST(clist));
 
-	designer = gtk_object_get_data(GTK_OBJECT(clist), "GNOME_DB_DesignerWidget");
+	designer = gtk_object_get_data (GTK_OBJECT (clist),
+					"GNOME_DB_DesignerWidget");
 	table_name = get_current_name_from_tree(designer);
 	if (GNOME_DB_IS_DESIGNER(designer) && table_name) {
 		GtkWidget *dialog;
-		GtkWidget *frame;
 		GtkWidget *table;
 		GtkWidget *label;
 		GtkWidget *name_entry;
@@ -241,10 +242,8 @@ table_add_field_cb (GtkWidget *w, gpointer user_data)
 					  GNOME_STOCK_BUTTON_CANCEL,
 					  NULL);
 		gnome_dialog_set_default(GNOME_DIALOG(dialog), 0);
-		frame = gnome_db_new_frame_widget(NULL);
-		gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), frame, TRUE, TRUE, 0);
 		table = gnome_db_new_table_widget(3, 4, FALSE);
-		gtk_container_add(GTK_CONTAINER(frame), table);
+		gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (dialog)->vbox), table, TRUE, TRUE, 0);
 
 		label = gnome_db_new_label_widget(_("Name"));
 		gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
@@ -256,8 +255,8 @@ table_add_field_cb (GtkWidget *w, gpointer user_data)
 	run_dialog:
 		if (!gnome_dialog_run(GNOME_DIALOG(dialog))) {
 			gchar *name_str;
-			GdaXmlTable *xml_table;
-			GdaXmlField *xml_field;
+			GdaXmlDatabaseTable *xml_table;
+			GdaXmlDatabaseField *xml_field;
 
 			/* check data entered by user */
 			name_str = gtk_entry_get_text(GTK_ENTRY(name_entry));
@@ -291,6 +290,15 @@ table_add_field_cb (GtkWidget *w, gpointer user_data)
 	}
 }
 
+static void
+xmldb_changed_cb (GdaXmlDatabase *xmldb, gpointer user_data)
+{
+	GnomeDbDesigner *designer = (GnomeDbDesigner *) user_data;
+
+	g_return_if_fail (GNOME_DB_IS_DESIGNER (designer));
+	gnome_db_designer_refresh (designer);
+}
+
 /*
  * GnomeDbDesigner widget interface
  */
@@ -313,11 +321,12 @@ gnome_db_designer_init (GnomeDbDesigner *designer)
 	designer->priv = g_new0(GnomeDbDesignerPrivate, 1);
 
 	/* create main container */
-	pane = e_hpaned_new();
-	gtk_widget_show(pane);
-	gtk_box_pack_start(GTK_BOX(designer), pane, 1, 1, 0);
+	pane = e_hpaned_new ();
+	gtk_container_set_border_width (GTK_CONTAINER (pane), 5);
+	gtk_widget_show (pane);
+	gtk_box_pack_start (GTK_BOX (designer), pane, 1, 1, 0);
 
-	frame = gnome_db_new_frame_widget(NULL);
+	frame = gnome_db_new_frame_widget (NULL);
 	e_paned_pack1(E_PANED(pane), frame, FALSE, FALSE);
 	scroll = gnome_db_new_scrolled_window_widget();
 	gtk_container_add(GTK_CONTAINER(frame), scroll);
@@ -372,10 +381,10 @@ gnome_db_designer_new (void)
 {
 	GnomeDbDesigner* designer;
 	
-	designer = GNOME_DB_DESIGNER(gtk_type_new(gnome_db_designer_get_type()));
-	designer->priv->xmldb = gda_xml_database_new();
+	designer = GNOME_DB_DESIGNER (gtk_type_new (gnome_db_designer_get_type ()));
+	designer->priv->xmldb = gda_xml_database_new ();
 	
-	return GTK_WIDGET(designer);
+	return GTK_WIDGET (designer);
 }
 
 /**
@@ -386,10 +395,10 @@ gnome_db_designer_new_from_file (const gchar *filename)
 {
 	GnomeDbDesigner* designer;
 	
-	designer = GNOME_DB_DESIGNER(gnome_db_designer_new());
-	gnome_db_designer_load_file(designer, filename);
+	designer = GNOME_DB_DESIGNER (gnome_db_designer_new ());
+	gnome_db_designer_load_file (designer, filename);
 	
-	return GTK_WIDGET(designer);
+	return GTK_WIDGET (designer);
 }
 
 /**
@@ -404,7 +413,12 @@ gnome_db_designer_new_from_xml (GdaXmlDatabase *xmldb)
 	GnomeDbDesigner* designer;
 	
 	designer = GNOME_DB_DESIGNER(gtk_type_new(gnome_db_designer_get_type()));
+	gtk_object_ref (GTK_OBJECT (xmldb));
 	designer->priv->xmldb = xmldb;
+	gtk_signal_connect (GTK_OBJECT (designer->priv->xmldb),
+			    "changed",
+			    GTK_SIGNAL_FUNC (xmldb_changed_cb),
+			    designer);
 	gnome_db_designer_refresh(designer);
 
 	return GTK_WIDGET(designer);
@@ -423,7 +437,6 @@ gnome_db_designer_destroy (GtkObject *object)
 
 	g_free((gpointer) designer->priv->filename);
 	gda_xml_database_free(designer->priv->xmldb);
-	
 
 	g_free((gpointer) designer->priv);
 
@@ -446,16 +459,26 @@ gnome_db_designer_load_file (GnomeDbDesigner *designer, const gchar *filename)
 	
 	xmldb = gda_xml_database_new_from_file(filename);
 	if (GDA_IS_XML_DATABASE(xmldb)) {
-		if (GDA_IS_XML_DATABASE(designer->priv->xmldb))
+		/* free the previous database, if any */
+		if (GDA_IS_XML_DATABASE(designer->priv->xmldb)) {
+			gtk_signal_disconnect_by_data (
+				GTK_OBJECT (designer->priv->xmldb),
+				designer);
 			gda_xml_database_free(designer->priv->xmldb);
+		}
 		if (designer->priv->filename)
 			g_free((gpointer) designer->priv->filename);
 
 		designer->priv->xmldb = xmldb;
+		gtk_signal_connect (GTK_OBJECT (designer->priv->xmldb),
+				    "changed",
+				    GTK_SIGNAL_FUNC (xmldb_changed_cb),
+				    designer);
 		designer->priv->filename = g_strdup(filename);
 		gnome_db_designer_refresh(designer);
 	}
-	else gnome_db_show_error(_("File %s is not a valid XML file"), filename);
+	else
+		gnome_db_show_error(_("File %s is not a valid XML file"), filename);
 }
 
 /**
@@ -493,40 +516,45 @@ gnome_db_designer_save (GnomeDbDesigner *designer)
 void
 gnome_db_designer_refresh (GnomeDbDesigner *designer)
 {
-	xmlNodePtr   xmlnode;
-	xmlNodePtr   xmlchild;
-	GnomePixmap* pixmap;
+	GList *list;
+	GList *l;
+	GnomePixmap *pixmap;
 	
 	g_return_if_fail(GNOME_DB_IS_DESIGNER(designer));
-	
+
 	gtk_ctree_remove_node(GTK_CTREE(designer->priv->object_tree), designer->priv->tables_node);
 	gtk_ctree_remove_node(GTK_CTREE(designer->priv->object_tree), designer->priv->views_node);
 	add_object_nodes(designer);
-	
+
 	/* get pixmaps */
 	pixmap = gnome_db_get_pixmap(GNOME_STOCK_MENU_BOOK_RED);
 	
 	/* refresh list of tables */
-	if ((xmlnode = gda_xml_database_get_tables(designer->priv->xmldb))) {
-		for (xmlchild = xmlnode->childs;
-		     xmlchild != NULL;
-		     xmlchild = xmlchild->next) {
-			gchar*        ctree_row[2] = { "", "" };
+	if ((list = gda_xml_database_get_tables(designer->priv->xmldb))) {
+		for (l = list; l != NULL; l = g_list_next (l)) {
+			gchar *ctree_row[2] = { "", "" };
 			GtkCTreeNode* new_node;
-			
-			ctree_row[1] = (gchar *) gda_xml_database_table_get_name(designer->priv->xmldb, xmlchild);
-			new_node = gtk_ctree_insert_node(GTK_CTREE(designer->priv->object_tree),
-			                                 designer->priv->tables_node, NULL,
-			                                 ctree_row, 0,
-			                                 GNOME_PIXMAP(pixmap)->pixmap,
-			                                 GNOME_PIXMAP(pixmap)->mask,
-			                                 GNOME_PIXMAP(pixmap)->pixmap,
-			                                 GNOME_PIXMAP(pixmap)->mask,
-			                                 TRUE, FALSE);
-			gtk_ctree_node_set_row_data(GTK_CTREE(designer->priv->object_tree),
-			                            new_node,
-			                            (gpointer) xmlchild);
+			GdaXmlDatabaseTable *xml_table;
+
+			xml_table = gda_xml_database_table_find (designer->priv->xmldb,
+								 (const gchar *) l->data);
+			ctree_row[1] = (gchar *) l->data;
+			new_node = gtk_ctree_insert_node (
+				GTK_CTREE (designer->priv->object_tree),
+				designer->priv->tables_node, NULL,
+				ctree_row, 0,
+				GNOME_PIXMAP (pixmap)->pixmap,
+				GNOME_PIXMAP (pixmap)->mask,
+				GNOME_PIXMAP (pixmap)->pixmap,
+				GNOME_PIXMAP (pixmap)->mask,
+				TRUE, FALSE);
+			gtk_ctree_node_set_row_data (
+				GTK_CTREE (designer->priv->object_tree),
+				new_node,
+				(gpointer) xml_table);
 		}
+		g_list_foreach (list, (GFunc) g_free, NULL);
+		g_list_free (list);
 	}
 }
 
