@@ -20,8 +20,8 @@
 #if !defined(__gnome_db_embeddable_h__)
 #  define __gnome_db_embeddable_h__
 
-#include <gnome.h>
-#include <bonobo.h>
+#include <libgnome/gnome-defs.h>
+#include <bonobo/bonobo-object.h>
 
 BEGIN_GNOME_DECLS
 
