@@ -1,5 +1,9 @@
-/* GNOME DB libary
- * Copyright (C) 1998,1999 Michael Lausch
+/* GNOME DB library
+ * Copyright (C) 1998-2001, The Free Software Foundation
+ *
+ * AUTHORS:
+ *	Michael Lausch <michael@lausch.at>
+ *	Rodrigo Moya <rodrigo@gnome-db.org>
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -17,8 +21,8 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifndef __gda_dberror_h__
-#define __gda_dberror_h__ 1
+#ifndef __gnome_db_error_h__
+#define __gnome_db_error_h__ 1
 
 #include <gtk/gtkvbox.h>
 #include <libgnome/gnome-defs.h>
@@ -32,37 +36,31 @@ BEGIN_GNOME_DECLS
 #define GNOME_DB_IS_ERROR(obj)         GTK_CHECK_TYPE(obj, GNOME_DB_TYPE_ERROR)
 #define GNOME_DB_IS_ERROR_CLASS(klass) (GTK_CHECK_CLASS_TYPE((klass), GNOME_DB_TYPE_ERROR))
 
-typedef struct _GnomeDbError           GnomeDbError;
-typedef struct _GnomeDbErrorClass      GnomeDbErrorClass;
+typedef struct _GnomeDbError        GnomeDbError;
+typedef struct _GnomeDbErrorClass   GnomeDbErrorClass;
+typedef struct _GnomeDbErrorPrivate GnomeDbErrorPrivate;
 
-struct _GnomeDbError
-{
-  GtkVBox         box;
-  GdaConnection* cnc;
-  GtkWidget*      description;
-  GtkWidget*      source;
-  GtkWidget*      sqlstate;
-  GtkWidget*      help_button;
-  GList*          error_ptr;
-  GtkWidget*      position_label;
-  gint            position;
+struct _GnomeDbError {
+	GtkVBox              box;
+	GnomeDbErrorPrivate* priv;
 };
 
-struct _GnomeDbErrorClass
-{
-  GtkVBoxClass      parent_class;
-  void              (*next)(GnomeDbError* error);
-  void              (*prev)(GnomeDbError* error);
+struct _GnomeDbErrorClass {
+	GtkVBoxClass parent_class;
+
+	/* signals */
+	void (*next)(GnomeDbError* error);
+	void (*prev)(GnomeDbError* error);
 };
 
-guint                         gnome_db_error_get_type   (void);
+guint          gnome_db_error_get_type       (void);
 
-GtkWidget*                    gnome_db_error_new        (GdaConnection* cnc);
-void                          gnome_db_error_error      (GnomeDbError* error_widget);
-void                          gnome_db_error_free       (GnomeDbError* error_widget);
-void                          gnome_db_error_show       (GnomeDbError* error_widget);
-void                          gnome_db_error_prev       (GnomeDbError* error_widget);
-void                          gnome_db_error_next       (GnomeDbError* error_widget);
+GtkWidget*     gnome_db_error_new            (void);
+void           gnome_db_error_clear          (GnomeDbError *error_widget);
+void           gnome_db_error_show           (GnomeDbError *error_widget,
+                                              GList *errors);
+void           gnome_db_error_prev           (GnomeDbError *error_widget);
+void           gnome_db_error_next           (GnomeDbError *error_widget);
 
 							 
 END_GNOME_DECLS
