@@ -615,6 +615,19 @@ gnome_db_grid_select_all (GnomeDbGrid *grid)
 }
 
 /**
+ *  gnome_db_grid_set_selection_mode
+ *  @grid: the grid widget
+ *  
+ *  Set the  selection mode in the given grid
+ */
+void
+gnome_db_grid_set_selection_mode (GnomeDbGrid *grid, GtkSelectionMode mode)
+{
+        g_return_if_fail(GNOME_DB_IS_GRID(grid));
+        gtk_clist_set_selection_mode(GTK_CLIST(grid->grid), mode);
+}
+
+/*
  * gnome_db_grid_clear_selection
  * @grid: the grid widget
  *
@@ -647,6 +660,25 @@ gnome_db_grid_get_selected_rows (GnomeDbGrid *grid)
 	return (0);
 }
 
+/**
+ * gnome_db_grid_get_selection
+ * @grid: the grid widget
+ *
+ * Retrieve the currently selected rows from the given grid widget.
+ * The returned GList is a static one, so don't try to free it. Each
+ * node in the returned list is an integer which represents the number
+ * of a selected row.
+ *
+ * Returns: a GList of integers. Each node can be retrieved using the
+ * GPOINTER_TO_INT GLib macro.
+ */
+GList *
+gnome_db_grid_get_selection (GnomeDbGrid *grid)
+{
+	g_return_val_if_fail (GNOME_DB_IS_GRID (grid), NULL);
+	return GTK_CLIST (grid->grid)->selection;
+}
+
 /**
  * gnome_db_grid_copy_clipboard
  * @grid: the grid widget
