@@ -68,6 +68,8 @@ void           gnome_db_grid_set_foreground        (GnomeDbGrid *grid,
                                                     GdkColor *color);
 
 void           gnome_db_grid_select_all            (GnomeDbGrid *grid);
+void           gnome_db_grid_set_selection_mode    (GnomeDbGrid *grid,
+                                                    GtkSelectionMode mode);
 void           gnome_db_grid_clear_selection       (GnomeDbGrid *grid);
 gint           gnome_db_grid_get_selected_rows     (GnomeDbGrid *grid);
 GList*         gnome_db_grid_get_selection         (GnomeDbGrid *grid);
