@@ -20,7 +20,8 @@
 #ifndef __gnome_db_icon_list_h__
 #define __gnome_db_icon_list_h__ 1
 
-#include <gnome.h>
+#include <gtk/gtkvbox.h>
+#include <libgnome/gnome-defs.h>
 #include <gda-recordset.h>
 
 BEGIN_GNOME_DECLS
@@ -34,37 +35,35 @@ BEGIN_GNOME_DECLS
 typedef struct _GnomeDbIconList      GnomeDbIconList;
 typedef struct _GnomeDbIconListClass GnomeDbIconListClass;
 
-struct _GnomeDbIconList
-{
-  GtkVBox        box;
-  GtkWidget*     scrolled_window;
-  GtkWidget*     list;
-  Gda_Recordset* recset;
-  gint           pos;
-  gint           total_rows;
-  gint           timeout_handle;
-  gchar*         pixmap_file;
-  GList*         values;
+struct _GnomeDbIconList {
+	GtkVBox        box;
+	GtkWidget*     scrolled_window;
+	GtkWidget*     list;
+	GdaRecordset* recset;
+	gint           pos;
+	gint           total_rows;
+	gint           timeout_handle;
+	gchar*         pixmap_file;
+	GList*         values;
 };
 
-struct _GnomeDbIconListClass
-{
-  GtkVBoxClass parent_class;
-  
-  void (*loaded)    (GnomeDbIconList *icon_list);
-  void (*add_row)   (GnomeDbIconList *icon_list);
-  void (*select_row)(GnomeDbIconList *icon_list);
+struct _GnomeDbIconListClass {
+	GtkVBoxClass parent_class;
+
+	void (*loaded)    (GnomeDbIconList *icon_list);
+	void (*add_row)   (GnomeDbIconList *icon_list);
+	void (*select_row)(GnomeDbIconList *icon_list);
 };
 
 guint          gnome_db_icon_list_get_type      (void);
-GtkWidget*     gnome_db_icon_list_new           (Gda_Recordset *recset, gint pos);
+GtkWidget*     gnome_db_icon_list_new           (GdaRecordset *recset, gint pos);
 void           gnome_db_icon_list_clear         (GnomeDbIconList *icon_list);
 
 const gchar*   gnome_db_icon_list_get_string    (GnomeDbIconList *icon_list);
 #define        gnome_db_icon_list_get_row_count(icon_list) GNOME_DB_ICON_LIST(icon_list)->total_rows)
-Gda_Recordset* gnome_db_icon_list_get_recordset (GnomeDbIconList *icon_list);
+GdaRecordset*  gnome_db_icon_list_get_recordset (GnomeDbIconList *icon_list);
 void           gnome_db_icon_list_set_recordset (GnomeDbIconList *icon_list,
-                                                 Gda_Recordset *recset,
+                                                 GdaRecordset *recset,
                                                  gint pos);
 const gchar*   gnome_db_icon_list_get_pixmap    (GnomeDbIconList *icon_list);
 void           gnome_db_icon_list_set_pixmap    (GnomeDbIconList *icon_list, gchar *pixmap);
