@@ -17,7 +17,8 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <gnome-db.h>
+#include "gnome-db.h"
+#include <libgnome/gnome-i18n.h>
 
 /**
  * gnome_db_init
@@ -31,11 +32,14 @@
  * any of gtk_init, gnome_init*, or bonobo_init when using this function.
  */
 void
-gnome_db_init (const gchar *app_id, const gchar *version, int nargs, char *args[]) {
+gnome_db_init (const gchar *app_id, const gchar *version, int nargs, char *args[])
+{
 	CORBA_Environment ev;
 	
 	gnome_init_with_popt_table(app_id, version, nargs, args, oaf_popt_options, 0, NULL);
-	oaf_init(nargs, args);
+
+	if (!oaf_is_initialized ())
+		oaf_init(nargs, args);
 	
 	/* initialize Bonobo */
 	if (bonobo_init(gda_corba_get_orb(), NULL, NULL) == FALSE)
@@ -60,7 +64,8 @@ gnome_db_init (const gchar *app_id, const gchar *version, int nargs, char *args[
  * called repeatedly until you do so.
  */
 void
-gnome_db_main (GtkFunction ui_create_func) {
+gnome_db_main (GtkFunction ui_create_func)
+{
 	if (ui_create_func) {
 		/*
 		 * We can't make any CORBA calls unless we're in the main
