@@ -21,17 +21,22 @@
 
 struct _GnomeDbLabelPrivate {
 	GdaRecordset* recset;
-	gint           col;
+	gint          col;
 };
 
+static void gnome_db_label_class_init (GnomeDbLabelClass *klass);
+static void gnome_db_label_init       (GnomeDbLabel *label);
+static void gnome_db_label_destroy    (GtkObject *object);
+
 /*
  * Callbacks
  */
 static void
-row_changed_cb (GdaRecordset *rs, GnomeDbLabel *label) {
+row_changed_cb (GdaRecordset *rs, GnomeDbLabel *label)
+{
 	GdaField* field;
 	
-	g_return_if_fail(IS_GDA_RECORDSET(rs));
+	g_return_if_fail(GDA_IS_RECORDSET(rs));
 	g_return_if_fail(GNOME_DB_IS_LABEL(label));
 	g_return_if_fail(label->priv->recset == rs);
 	
@@ -45,51 +50,62 @@ row_changed_cb (GdaRecordset *rs, GnomeDbLabel *label) {
  * Private functions
  */
 static void
-_gnome_db_label_destroy (GnomeDbLabel *label, gpointer user_data) {
+gnome_db_label_destroy (GtkObject *object)
+{
+	GtkObjectClass *parent_class;
+	GnomeDbLabel *label = (GnomeDbLabel *) object;
+
 	g_return_if_fail(GNOME_DB_IS_LABEL(label));
 	
 	if (label->priv) {
-		if (IS_GDA_RECORDSET(label->priv->recset))
+		if (GDA_IS_RECORDSET(label->priv->recset))
 			gtk_object_unref(GTK_OBJECT(label->priv->recset));
 		g_free((gpointer) label->priv);
+		label->priv = NULL;
 	}
+
+	parent_class = gtk_type_class (gtk_label_get_type ());
+	if (parent_class && parent_class->destroy)
+		parent_class->destroy (object);
 }
 
 static void
-_gnome_db_label_class_init (GnomeDbLabelClass *klass) {
+gnome_db_label_class_init (GnomeDbLabelClass *klass)
+{
+	GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
+
+	object_class->destroy = gnome_db_label_destroy;
 }
 
 static void
-_gnome_db_label_init (GnomeDbLabel *label) {
+gnome_db_label_init (GnomeDbLabel *label)
+{
 	g_return_if_fail(GNOME_DB_IS_LABEL(label));
 	
 	label->priv = g_new0(GnomeDbLabelPrivate, 1);
-	gtk_signal_connect(GTK_OBJECT(label),
-	                   "destroy",
-	                   GTK_SIGNAL_FUNC(_gnome_db_label_destroy),
-	                   NULL);
 }
 
 /*
  * Public functions
  */
 GtkType
-gnome_db_label_get_type (void) {
-	static GtkType db_label_type = 0;
+gnome_db_label_get_type (void)
+{
+	static GtkType type = 0;
 	
-	if (!db_label_type) {
-		GtkTypeInfo db_label_info = {
+	if (!type) {
+		GtkTypeInfo info = {
 			"GnomeDbLabel",
 			sizeof (GnomeDbLabel),
 			sizeof (GnomeDbLabelClass),
-			(GtkClassInitFunc) _gnome_db_label_class_init,
-			(GtkObjectInitFunc) _gnome_db_label_init,
+			(GtkClassInitFunc) gnome_db_label_class_init,
+			(GtkObjectInitFunc) gnome_db_label_init,
 			(GtkArgSetFunc) NULL,
 			(GtkArgGetFunc) NULL
 		};
-		db_label_type = gtk_type_unique(gtk_label_get_type(), &db_label_info);
+		type = gtk_type_unique(gtk_label_get_type(), &info);
 	}
-	return (db_label_type);
+	return type;
 }
 
 /**
@@ -98,11 +114,12 @@ gnome_db_label_get_type (void) {
  * @col: column index in recordset
  */
 GtkWidget *
-gnome_db_label_new (GdaRecordset *recset, gint col) {
+gnome_db_label_new (GdaRecordset *recset, gint col)
+{
 	GnomeDbLabel* label;
 	
 	label = GNOME_DB_LABEL(gtk_type_new(gnome_db_label_get_type()));
-	if (IS_GDA_RECORDSET(recset))
+	if (GDA_IS_RECORDSET(recset))
 		gnome_db_label_set_recordset(label, recset, col);
 	return GTK_WIDGET(label);
 }
@@ -111,7 +128,8 @@ gnome_db_label_new (GdaRecordset *recset, gint col) {
  * gnome_db_label_get_recordset
  */
 GdaRecordset *
-gnome_db_label_get_recordset (GnomeDbLabel *label) {
+gnome_db_label_get_recordset (GnomeDbLabel *label)
+{
 	g_return_val_if_fail(GNOME_DB_IS_LABEL(label), NULL);
 	g_return_val_if_fail(label->priv != NULL, NULL);
 	
@@ -122,18 +140,20 @@ gnome_db_label_get_recordset (GnomeDbLabel *label) {
  * gnome_db_label_set_recordset
  */
 void
-gnome_db_label_set_recordset (GnomeDbLabel *label, GdaRecordset *recset, gint col) {
+gnome_db_label_set_recordset (GnomeDbLabel *label, GdaRecordset *recset, gint col)
+{
 	g_return_if_fail(GNOME_DB_IS_LABEL(label));
 	g_return_if_fail(label->priv != NULL);
 	
 	/* remove the currently active recordset */
-	if (IS_GDA_RECORDSET(label->priv->recset)) {
+	if (GDA_IS_RECORDSET(label->priv->recset)) {
 		gtk_signal_disconnect(GTK_OBJECT(label->priv->recset),
 		                      gtk_signal_lookup("row_changed", gda_recordset_get_type()));
-		gtk_object_unref(GTK_OBJECT(label->priv->recset));
+		gda_recordset_free (label->priv->recset);
 	}
 	
 	/* set the new recordset */
+	gtk_object_ref (GTK_OBJECT (label->priv->recset));
 	label->priv->recset = recset;
 	label->priv->col = col;
 	gtk_signal_connect(GTK_OBJECT(label->priv->recset),
@@ -147,7 +167,8 @@ gnome_db_label_set_recordset (GnomeDbLabel *label, GdaRecordset *recset, gint co
  * gnome_db_label_get_text
  */
 const gchar *
-gnome_db_label_get_text (GnomeDbLabel *label) {
+gnome_db_label_get_text (GnomeDbLabel *label)
+{
 	gchar* str = NULL;
 	
 	g_return_val_if_fail(GNOME_DB_IS_LABEL(label), NULL);
@@ -159,7 +180,8 @@ gnome_db_label_get_text (GnomeDbLabel *label) {
  * gnome_db_label_set_text
  */
 void
-gnome_db_label_set_text (GnomeDbLabel *label, const gchar *txt) {
+gnome_db_label_set_text (GnomeDbLabel *label, const gchar *txt)
+{
 	g_return_if_fail(GNOME_DB_IS_LABEL(label));
 	gtk_label_set_text(GTK_LABEL(label), txt);
 }
