@@ -20,7 +20,8 @@
 #ifndef __gnome_db_list_h__
 #define __gnome_db_list_h__ 1
 
-#include <gnome.h>
+#include <gtk/gtkvbox.h>
+#include <libgnome/gnome-defs.h>
 #include <gda-recordset.h>
 
 BEGIN_GNOME_DECLS
@@ -36,41 +37,41 @@ typedef struct _GnomeDbListClass GnomeDbListClass;
 
 struct _GnomeDbList
 {
-  GtkVBox        vbox;
+	GtkVBox       vbox;
 
-  GtkWidget*     list;
-  Gda_Recordset* recset;
-  gint           col;
-  gint           timeout_handle;
-  gint           total_rows;
+	GtkWidget*    list;
+	GdaRecordset* recset;
+	gint          col;
+	gint          timeout_handle;
+	gint          total_rows;
 };
 
 struct _GnomeDbListClass
 {
-  GtkVBoxClass parent_class;
+	GtkVBoxClass parent_class;
 
-  void         (*loaded)(GnomeDbList *dblist);
-  void         (*select_row)(GnomeDbList *dblist);
-  void         (*add_row)(GnomeDbList *dblist, gint row);
+	void         (*loaded)(GnomeDbList *dblist);
+	void         (*select_row)(GnomeDbList *dblist);
+	void         (*add_row)(GnomeDbList *dblist, gint row);
 };
 
-guint          gnome_db_list_get_type        (void);
-GtkWidget*     gnome_db_list_new             (Gda_Recordset *recset, gint pos);
-void           gnome_db_list_clear           (GnomeDbList *dblist);
+guint         gnome_db_list_get_type        (void);
+GtkWidget*    gnome_db_list_new             (GdaRecordset *recset, gint pos);
+void          gnome_db_list_clear           (GnomeDbList *dblist);
 
-gint           gnome_db_list_get_row_count   (GnomeDbList *dblist);
-gchar*         gnome_db_list_get_string      (GnomeDbList *dblist);
-Gda_Recordset* gnome_db_list_get_recordset   (GnomeDbList *dblist);
-void           gnome_db_list_set_recordset   (GnomeDbList *dblist,
-                                              Gda_Recordset *recset,
-                                              gint pos);
+gint          gnome_db_list_get_row_count   (GnomeDbList *dblist);
+gchar*        gnome_db_list_get_string      (GnomeDbList *dblist);
+GdaRecordset* gnome_db_list_get_recordset   (GnomeDbList *dblist);
+void          gnome_db_list_set_recordset   (GnomeDbList *dblist,
+											 GdaRecordset *recset,
+											 gint pos);
 
-GdkPixmap*     gnome_db_list_get_pixmap      (GnomeDbList *dblist, gint row);
-void           gnome_db_list_set_pixmap      (GnomeDbList *dblist,
-                                              gint row,
-                                              GdkPixmap *pixmap,
-                                              GdkBitmap *mask);
-GdkBitmap*     gnome_db_list_get_pixmap_mask (GnomeDbList *dblist, gint row);
+GdkPixmap*    gnome_db_list_get_pixmap      (GnomeDbList *dblist, gint row);
+void          gnome_db_list_set_pixmap      (GnomeDbList *dblist,
+											 gint row,
+											 GdkPixmap *pixmap,
+											 GdkBitmap *mask);
+GdkBitmap*    gnome_db_list_get_pixmap_mask (GnomeDbList *dblist, gint row);
 
 END_GNOME_DECLS
 
