@@ -18,6 +18,7 @@
  */
  
 #include "gnome-db.h"
+#include <libgnome/gnome-i18n.h>
 #include <libgnomeprint/gnome-print.h>
 #include <libgnomeprint/gnome-print-dialog.h>
 #include <libgnomeprint/gnome-printer.h>
@@ -28,18 +29,31 @@ static GnomePrinter* default_printer = NULL;
 void
 gnome_db_print_setup_dlg_cb (GtkWidget *w, gpointer data)
 {
-  GtkWidget *dialog = gnome_print_dialog_new(_("Setup Printer"), 0);
-  gnome_dialog_set_default(GNOME_DIALOG(dialog), GNOME_PRINT_PRINT);
-  if (gnome_dialog_run(GNOME_DIALOG(dialog)) == GNOME_PRINT_PRINT)
-    {
-      default_printer = gnome_print_dialog_get_printer(GNOME_PRINT_DIALOG(dialog));
-    }
-  gnome_dialog_close(GNOME_DIALOG(dialog));
+	GtkWidget *dialog;
+	
+	dialog = gnome_print_dialog_new(_("Setup Printer"), 0);
+	gnome_dialog_set_default(GNOME_DIALOG(dialog), GNOME_PRINT_PRINT);
+	if (gnome_dialog_run(GNOME_DIALOG(dialog)) == GNOME_PRINT_PRINT) {
+		GnomePrinter *printer;
+
+		printer = gnome_print_dialog_get_printer(GNOME_PRINT_DIALOG(dialog));
+
+		/* only set new printer if it works */
+		if (printer && gnome_printer_get_status(printer) == GNOME_PRINTER_ACTIVE) {
+			if (GNOME_IS_PRINTER(default_printer))
+				gnome_printer_unref(default_printer);
+
+			gnome_printer_ref(printer);
+			default_printer = printer;
+		}
+	}
+	gnome_dialog_close(GNOME_DIALOG(dialog));
 }
 
 GnomePrinter *
 gnome_db_print_get_printer (void)
 {
-  if (!default_printer) gnome_db_print_setup_dlg_cb(NULL, NULL);
+  if (!default_printer)
+  	gnome_db_print_setup_dlg_cb(NULL, NULL);
   return default_printer;
 }
