@@ -20,8 +20,8 @@
 #ifndef __gnome_db_report_h__
 #define __gnome_db_report_h__ 1
 
-#include <gnome.h>
-
+#include <gtk/gtkvbox.h>
+#include <libgnome/gnome-defs.h>
 #include <gnome-xml/parser.h>
 #include <gnome-xml/tree.h>
 
