@@ -25,14 +25,25 @@
  * Public functions
  */
 static void
-gnome_db_shortcut_realize (GnomeDbShortcut *shortcut, gpointer data)
+gnome_db_shortcut_realize (GnomeDbShortcut *shortcut)
 {
+	GtkObjectClass *parent_class;
+
 	g_return_if_fail(GNOME_DB_IS_SHORTCUT(shortcut));
+
+	parent_class = gtk_type_class (gtk_vbox_get_type ());
+	if (GTK_WIDGET_CLASS (parent_class)->realize)
+		GTK_WIDGET_CLASS (parent_class)->realize (GTK_WIDGET (shortcut));
+
+	gnome_db_set_bg_color(GTK_WIDGET(shortcut), 1, 1, 1);
 }
 
 static void
 gnome_db_shortcut_class_init (GnomeDbShortcutClass *klass)
 {
+	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
+
+	widget_class->realize = gnome_db_shortcut_realize;
 }
 
 static void
@@ -40,32 +51,26 @@ gnome_db_shortcut_init (GnomeDbShortcut *shortcut)
 {
 	GtkWidget* frame;
 
-	gnome_db_set_bg_color(GTK_WIDGET(shortcut), 32767, 32767, 32767);
-	gtk_signal_connect_after(GTK_OBJECT(shortcut),
-				 "realize",
-				 GTK_SIGNAL_FUNC(gnome_db_shortcut_realize),
-				 NULL);
-
 	/* create the toolbar widget */
-	frame = gnome_db_new_frame_widget(NULL);
-	gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_IN);
-	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
-	gtk_box_pack_start(GTK_BOX(shortcut), frame, 1, 1, 0);
-	shortcut->tb = gnome_db_new_toolbar_widget(GTK_ORIENTATION_VERTICAL,
-						   GTK_TOOLBAR_BOTH,
-						   NULL, NULL);
-	gtk_toolbar_set_tooltips(GTK_TOOLBAR(shortcut->tb), FALSE);
-	gtk_container_set_border_width(GTK_CONTAINER(shortcut->tb), 8);
-	gtk_container_add(GTK_CONTAINER(frame), shortcut->tb);
+	frame = gnome_db_new_frame_widget (NULL);
+	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
+	gtk_container_set_border_width (GTK_CONTAINER (frame), 5);
+	gtk_box_pack_start (GTK_BOX (shortcut), frame, 1, 1, 0);
+	shortcut->tb = gnome_db_new_toolbar_widget (GTK_ORIENTATION_VERTICAL,
+						    GTK_TOOLBAR_BOTH,
+						    NULL, NULL);
+	gtk_toolbar_set_tooltips (GTK_TOOLBAR (shortcut->tb), FALSE);
+	gtk_container_set_border_width (GTK_CONTAINER (shortcut->tb), 8);
+	gtk_container_add (GTK_CONTAINER (frame), shortcut->tb);
 }
 
 GtkType
 gnome_db_shortcut_get_type (void)
 {
-	static GtkType db_shortcut_type = 0;
+	static GtkType type = 0;
 
-	if (!db_shortcut_type) {
-		GtkTypeInfo db_shortcut_info = {
+	if (!type) {
+		GtkTypeInfo info = {
 			"GnomeDbShortcut",
 			sizeof (GnomeDbShortcut),
 			sizeof (GnomeDbShortcutClass),
@@ -74,10 +79,9 @@ gnome_db_shortcut_get_type (void)
 			(GtkArgSetFunc) NULL,
 			(GtkArgGetFunc) NULL
 		};
-		db_shortcut_type = gtk_type_unique(gtk_vbox_get_type(),
-						   &db_shortcut_info);
+		type = gtk_type_unique (gtk_vbox_get_type (), &info);
 	}
-	return (db_shortcut_type);
+	return (type);
 }
 
 GtkWidget *
@@ -85,8 +89,8 @@ gnome_db_shortcut_new (void)
 {
 	GnomeDbShortcut* shortcut;
 
-	shortcut = GNOME_DB_SHORTCUT(gtk_type_new(gnome_db_shortcut_get_type()));
-	return GTK_WIDGET(shortcut);
+	shortcut = GNOME_DB_SHORTCUT (gtk_type_new (gnome_db_shortcut_get_type ()));
+	return GTK_WIDGET (shortcut);
 }
 
 void
@@ -104,9 +108,9 @@ gnome_db_shortcut_append (GnomeDbShortcut *shortcut,
 
 	pixmap = gnome_stock_new_with_icon(icon_file);
 	gtk_widget_show(pixmap);
-	gtk_toolbar_append_space(GTK_TOOLBAR(shortcut->tb));
-	gtk_toolbar_append_item(GTK_TOOLBAR(shortcut->tb), _(str),
-				_(tooltip), NULL, pixmap, select_func, user_data);
+	gtk_toolbar_append_space (GTK_TOOLBAR(shortcut->tb));
+	gtk_toolbar_append_item (GTK_TOOLBAR(shortcut->tb), _(str),
+				 _(tooltip), NULL, pixmap, select_func, user_data);
 }
 
 void
