@@ -309,6 +309,22 @@ gnome_db_new_scrolled_window_widget (void)
 	return (scrolled_window);
 }
 
+GtkWidget *
+gnome_db_new_spin_button_widget (gfloat init_value,
+				 gfloat lower,
+				 gfloat upper,
+				 guint dec_digits)
+{
+	GtkAdjustment *adj;
+	GtkWidget *spin_button;
+
+	adj = gtk_adjustment_new (init_value, lower, upper, 1, 1, 0);
+	spin_button = gtk_spin_button_new (adj, 1.0, dec_digits);
+	gtk_widget_show (spin_button);
+
+	return spin_button;
+}
+
 GtkWidget *
 gnome_db_new_status_bar_widget (void)
 {
@@ -316,6 +332,7 @@ gnome_db_new_status_bar_widget (void)
 	
 	status = gtk_statusbar_new();
 	gtk_widget_show(status);
+
 	return status;
 }
 
@@ -366,15 +383,15 @@ gnome_db_new_toolbar_widget (GtkOrientation orientation,
 	GtkWidget* toolbar;
 	gint cnt;
 	
-	toolbar = gtk_toolbar_new(orientation, style);
-	gtk_toolbar_set_button_relief(GTK_TOOLBAR(toolbar), GTK_RELIEF_NONE);
+	toolbar = gtk_toolbar_new (orientation, style);
+	gtk_toolbar_set_button_relief (GTK_TOOLBAR (toolbar), GTK_RELIEF_NONE);
 	if (uiinfo) {
 		for (cnt = 0; uiinfo[cnt].type != GNOME_APP_UI_ENDOFINFO; cnt++) {
 			uiinfo[cnt].user_data = user_data;
 		}
-		gnome_app_fill_toolbar(GTK_TOOLBAR(toolbar), uiinfo, NULL);
+		gnome_app_fill_toolbar (GTK_TOOLBAR (toolbar), uiinfo, NULL);
 	}
-	gtk_widget_show(toolbar);
+	gtk_widget_show (toolbar);
 	return toolbar;
 }
 
