@@ -20,7 +20,7 @@
 #include "gnomedb-mgr.h"
 
 static void
-activate_dsn_tab_cb (GtkWidget *w, GnomeDbControl *control)
+activate_dsn_tab_cb (BonoboUIComponent *uic, GnomeDbControl *control, const gchar *path)
 {
 	GtkWidget* notebook;
 	
@@ -30,7 +30,7 @@ activate_dsn_tab_cb (GtkWidget *w, GnomeDbControl *control)
 }
 
 static void
-activate_providers_tab_cb (GtkWidget *w, GnomeDbControl *control)
+activate_providers_tab_cb (BonoboUIComponent *uic, GnomeDbControl *control, const gchar *path)
 {
 	GtkWidget* notebook;
 	
@@ -39,28 +39,16 @@ activate_providers_tab_cb (GtkWidget *w, GnomeDbControl *control)
 		gtk_notebook_set_page(GTK_NOTEBOOK(notebook), 1);
 }
 
-GnomeUIInfo optionsmenu[] = {
-	GNOMEUIINFO_SEPARATOR,
-	{ GNOME_APP_UI_ITEM, N_("Data Sources"), N_("Manage connection data sources"),
-	  activate_dsn_tab_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
-	  GNOME_STOCK_MENU_MAIL, 0, 0, NULL },
-	{ GNOME_APP_UI_ITEM, N_("Providers"), N_("Manage available GDA providers"),
-	  activate_providers_tab_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
-	  GNOME_STOCK_MENU_CONVERT, 0, 0, NULL },
-	GNOMEUIINFO_END
-};
-static GnomeUIInfo manager_control_menu[] = {
-	GNOMEUIINFO_SUBTREE(N_("_Options"), optionsmenu),
-	GNOMEUIINFO_END
-};
-static GnomeUIInfo manager_control_toolbar[] = {
-	{ GNOME_APP_UI_ITEM, N_("Data Sources"), N_("Manage connection data sources"),
-	  activate_dsn_tab_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
-	  GNOME_STOCK_PIXMAP_MAIL, 0, 0, NULL },
-	{ GNOME_APP_UI_ITEM, N_("Providers"), N_("Manage available GDA providers"),
-	  activate_providers_tab_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
-	  GNOME_STOCK_PIXMAP_CONVERT, 0, 0, NULL },
-	GNOMEUIINFO_END
+static void
+new_dsn_cb (BonoboUIComponent *uic, GnomeDbControl *control, const gchar *path)
+{
+}
+
+BonoboUIVerb manager_verbs [] = {
+	BONOBO_UI_VERB ("ManagerNewDsn", new_dsn_cb),
+	BONOBO_UI_VERB ("ManagerDsns", activate_dsn_tab_cb),
+	BONOBO_UI_VERB ("ManagerProviders", activate_providers_tab_cb),
+	BONOBO_UI_VERB_END
 };
 
 BonoboObject *
@@ -79,8 +67,11 @@ manager_control_new (void)
 		manager_dsn_init(GTK_NOTEBOOK(notebook));
 		manager_providers_init(GTK_NOTEBOOK(notebook));
 		
-		gnome_db_control_set_menubar(control, manager_control_menu);
-		gnome_db_control_set_toolbar(control, manager_control_toolbar);
+		gnome_db_control_set_ui (control,
+					 GNOMEDB_DATADIR,
+					 "gnomedb-manager.xml",
+					 manager_verbs,
+					 control);
 	}
 	return BONOBO_OBJECT(control);
 }
