@@ -23,6 +23,7 @@
 static guint prepare_app (void);
 
 static BonoboGenericFactory* manager_factory = NULL;
+static gint owner_count = 0;
 
 int
 main (int argc, char *argv[])
@@ -37,16 +38,44 @@ main (int argc, char *argv[])
 	return 0;
 }
 
+static void
+owner_set_cb (GnomeDbControl *control, gpointer user_data)
+{
+	owner_count++;
+}
+
+static void
+owner_unset_cb (GnomeDbControl *control, gpointer user_data)
+{
+	owner_count--;
+	if (owner_count == 0)
+		gnome_db_main_quit ();
+}
+
 static BonoboObject *
 manager_factory_func (BonoboGenericFactory *factory, const char *id, gpointer closure)
 {
+	BonoboObject *object = NULL;
+
 	g_return_val_if_fail(BONOBO_IS_GENERIC_FACTORY(factory), NULL);
 	g_return_val_if_fail(id != NULL, NULL);
 
 	if (!strcmp(id, GNOME_DB_OAFIID_MANAGER))
-		return manager_control_new();
+		object = manager_control_new();
 
-	return NULL;
+	/* connect to set/get_owner signals */
+	if (BONOBO_IS_OBJECT (object)) {
+		gtk_signal_connect (GTK_OBJECT (object),
+				    "set_owner",
+				    GTK_SIGNAL_FUNC (owner_set_cb),
+				    NULL);
+		gtk_signal_connect (GTK_OBJECT (object),
+				    "unset_owner",
+				    GTK_SIGNAL_FUNC (owner_unset_cb),
+				    NULL);
+	}
+
+	return object;
 }
 
 static guint
