@@ -17,18 +17,19 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#if !defined(__gda_mgr_h__)
-#  define __gda_mgr_h__
+#if !defined(__gnomedb_mgr_h__)
+#  define __gnomedb_mgr_h__
 
+#include "config.h"
 #include <gnome-db.h>
-#include <config.h>
+#include <libgnome/gnome-i18n.h>
 
 BEGIN_GNOME_DECLS
 
 /*
  * Callbacks
  */
-GnomeDbControlInstance* manager_control_create_instance_cb (GnomeDbControl *control);
+BonoboObject* manager_control_new (void);
 
 /*
  * Data Sources
