@@ -33,6 +33,6 @@ extern void rolodex_quit_cb (GtkWidget *w, gpointer data);
  * Global variables
  */
 extern GtkWidget*      glb_mainwin;
-extern Gda_Connection* glb_connection;
+extern GdaConnection* glb_connection;
 
 #endif
